package com.ruoyi.ss.softwareVersion.mapper;


import com.ruoyi.ss.softwareVersion.domain.SoftwareVersion;

import java.util.List;

/**
 * 软件版本Mapper接口
 *
 * @author qiuzhenzhao
 * @date 2024-07-22
 */
public interface SoftwareVersionMapper
{
    /**
     * 查询软件版本
     *
     * @param id 软件版本主键
     * @return 软件版本
     */
    public SoftwareVersion selectEtSoftwareVersionById(Long id);

    /**
     * 查询软件版本列表
     *
     * @param etSoftwareVersion 软件版本
     * @return 软件版本集合
     */
    public List<SoftwareVersion> selectEtSoftwareVersionList(SoftwareVersion etSoftwareVersion);

    /**
     * 新增软件版本
     *
     * @param etSoftwareVersion 软件版本
     * @return 结果
     */
    public int insertEtSoftwareVersion(SoftwareVersion etSoftwareVersion);

    /**
     * 修改软件版本
     *
     * @param etSoftwareVersion 软件版本
     * @return 结果
     */
    public int updateEtSoftwareVersion(SoftwareVersion etSoftwareVersion);

    /**
     * 删除软件版本
     *
     * @param id 软件版本主键
     * @return 结果
     */
    public int deleteEtSoftwareVersionById(Long id);

    /**
     * 批量删除软件版本
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEtSoftwareVersionByIds(Long[] ids);
}
